@@ -3,7 +3,7 @@
 ** distribution information.
 */
 
-/* $Id: acconfig.h,v 1.9 2001/03/26 23:22:43 mrsam Exp $ */
+/* $Id: acconfig.h,v 1.13 2002/05/08 02:23:46 mrsam Exp $ */
 
 /* Whether we must provide a prototype for crypt() */
 #undef	NEED_CRYPT_PROTOTYPE
@@ -31,3 +31,15 @@
 
 /* Whether -lvpopmail has the vlogauth() function */
 #undef HAVE_VLOGAUTH
+
+/* Whether we have the expect() utility */
+#undef HAVE_EXPECT
+
+/* Whether password changing should be enabled */
+#undef AUTHCHANGEPASS
+
+/* Whether we have ldap_start_tls_s() */
+#undef HAVE_LDAP_TLS
+
+/* Whether we have ldap_result2error */
+#undef HAVE_LDAP_RESULT2ERROR
