@@ -136,6 +136,8 @@ struct ldap_info
 	int   deref;
 	int   tls;
 
+	const char *mailroot;
+
 	/* Optional emailmap to handle */
 
 	const char *emailmap;
@@ -423,6 +425,10 @@ static int authldap_read_config(struct ldap_info *ldap)
 	  ldap->deref = LDAP_DEREF_ALWAYS; 
   }
 
+  if (!read_env("LDAP_MAILROOT",&ldap->mailroot,"",0,NULL)
+      || ldap->mailroot == NULL || ldap->mailroot[0] == 0)
+	  ldap->mailroot=NULL;
+
   if (!read_env("LDAP_EMAILMAP", &ldap->emailmap, "", 0, "") ||
       !read_env("LDAP_EMAILMAP_BASEDN", &ldap->emailmap_basedn, "", 0, "") ||
       !read_env("LDAP_EMAILMAP_ATTRIBUTE", &ldap->emailmap_handle, "", 0, "")||
@@ -1003,6 +1009,25 @@ static int auth_ldap_do3(const char *attrname,
 	if (attributes[8])
 		copy_value(my_ldap_fp,entry,attributes[8],&quota, user);
 
+	if (homeDir != 0 && my_ldap.mailroot != 0 && *my_ldap.mailroot)
+	{
+		char *new_mailroot=malloc(strlen(homeDir)+
+					  strlen(my_ldap.mailroot)+2);
+
+		if (!new_mailroot)
+		{
+			syslog(LOG_DAEMON|LOG_CRIT, "authldap: malloc failed");
+			rc= -1;
+		}
+		else
+		{
+			strcat(strcat(strcpy(new_mailroot, my_ldap.mailroot),
+				      "/"), homeDir);
+			free(homeDir);
+			homeDir=new_mailroot;
+		}
+	}
+
 	auth.sysusername=user;
 	auth.sysuserid= &au;
 	auth.sysgroupid= ag;
