@@ -24,7 +24,7 @@
 #define		SV_BEGIN_LEN		((sizeof(SV_BEGIN_MARK))-1)
 #define		SV_END_LEN		((sizeof(SV_END_MARK))-1)
 
-static const char rcsid[]="$Id: authmysqllib.c,v 1.17 2002/04/01 19:56:18 mrsam Exp $";
+static const char rcsid[]="$Id: authmysqllib.c,v 1.19 2002/05/26 16:48:47 mrsam Exp $";
 
 /* siefca@pld.org.pl */
 struct var_data {			
@@ -159,9 +159,9 @@ const	char *p;
 		server_opt=(unsigned int) atol(p);
 	}
 
-	if (!server)
+	if (!server && !server_socket)
 	{
-		fprintf(stderr, "authmysql: MYSQL_SERVER not set in "
+		fprintf(stderr, "authmysql: MYSQL_SERVER nor MYSQL_SOCKET set in"
 			AUTHMYSQLRC ".\n");
 		return (-1);
 	}
