@@ -1,5 +1,5 @@
 /*
-** Copyright 1998 - 1999 Double Precision, Inc.
+** Copyright 1998 - 2002 Double Precision, Inc.
 ** See COPYING for distribution information.
 */
 
@@ -14,7 +14,7 @@
 #endif
 #include	"imapwrite.h"
 
-static const char rcsid[]="$Id: capability.c,v 1.4 2000/11/11 19:52:31 mrsam Exp $";
+static const char rcsid[]="$Id: capability.c,v 1.5 2002/05/29 17:25:26 mrsam Exp $";
 
 int have_starttls()
 {
@@ -59,5 +59,13 @@ const char *p;
 		if (tlsrequired())
 			writes(" LOGINDISABLED");
 	}
+
+	p=getenv("OUTBOX");
+
+	if (p && *p)
+	{
+		writes(" XCOURIEROUTBOX=INBOX");
+		writes(p);
+	}
 	writes("\r\n");
 }
