@@ -62,9 +62,10 @@
 #include	"storeinfo.h"
 #include	"mailboxlist.h"
 #include	"thread.h"
-
+#include	"outbox.h"
 #include	"authlib/authmod.h"
 
+#include	"maildir/config.h"
 #include	"maildir/maildircreate.h"
 #include	"maildir/maildirrequota.h"
 #include	"maildir/maildirgetquota.h"
@@ -75,7 +76,7 @@
 
 #define	SHARED	"shared"
 
-static const char rcsid[]="$Id: imapd.c,v 1.74 2002/04/06 15:48:39 mrsam Exp $";
+static const char rcsid[]="$Id: imapd.c,v 1.80 2002/07/02 20:01:37 mrsam Exp $";
 
 extern time_t rfc822_parsedt(const char *);
 extern void fetchflags(unsigned long);
@@ -115,52 +116,30 @@ void quotainfo_out(const char* qroot)
 	
 	if ((maildir_getquota(".", quotabuf) == 0) && (strcmp(qroot,"SHARED") != 0))
 	{
-	int	quotafd;
-	int	i,quota_s=-1,quota_c=-1;
-	char    *quota=quotabuf;
-	off_t		maildirsize_size=0;
-	unsigned	maildirsize_cnt=0;
-	unsigned	dummy;
-	struct	stat	stat_buf;
+		struct maildirsize quotainfo;
 
-		(void) maildir_checkquota(".", &quotafd, quotabuf, 0, 0);
-		if (quotafd >= 0)	close(quotafd);
-
-		if (maildirsize_read("maildirsize",&quotafd,
-			&maildirsize_size,&maildirsize_cnt,&dummy,&stat_buf) == 0)
-			close(quotafd);
-
-		while (quota && *quota)
-		{
-			if (*quota < '0' || *quota > '9')
-			{
-				++quota;
-				continue;
-			}
-
-			i=0;
-			while (*quota >= '0' && *quota <= '9')
-				i=i*10 + (*quota++ - '0');
-			switch (*quota) 
-			{
-				case 'S': quota_s=i; break;
-				case 'C': quota_c=i; break;
-				default : break;
-			}
-		}
+		if (maildir_openquotafile(&quotainfo, ".") == 0)
+			maildir_closequotafile(&quotainfo);
+		else
+			quotainfo.quota.nbytes=quotainfo.size.nbytes=
+				quotainfo.quota.nmessages=
+				quotainfo.size.nmessages=0;
 			
-		if (quota_s != -1)
+		if (quotainfo.quota.nbytes > 0)
 		{
-			sprintf(qbuf,"STORAGE %d %d",((int)maildirsize_size+1023)/1024,(quota_s+1023)/1024);
+			sprintf(qbuf,"STORAGE %ld %ld",
+				((long)quotainfo.size.nbytes+1023)/1024,
+				((long)quotainfo.quota.nbytes+1023)/1024);
 			strcat(qresult,qbuf);
 		}
-		if (quota_c != -1)
+		if (quotainfo.quota.nmessages > 0)
 		{
-			sprintf(qbuf,"MESSAGE %d %d",maildirsize_cnt,quota_c);
+			sprintf(qbuf,"MESSAGE %d %d",
+				quotainfo.size.nmessages,
+				quotainfo.quota.nmessages);
 			if (strcmp(qresult,"")!=0) strcat(qresult," ");
 			strcat(qresult,qbuf);
 		}
-		
 	}
 
 	writes("* ");
@@ -490,8 +469,8 @@ const char *filename=mi->filename;
 		flags->seen=flags->answered=flags->deleted=flags->flagged
 		=flags->recent=flags->drafts=0;
 
-	if ((filename=strrchr(filename, ':')) == 0
-		|| strncmp(filename, ":2,", 3))	return;
+	if ((filename=strrchr(filename, MDIRSEP[0])) == 0
+		|| strncmp(filename, MDIRSEP "2,", 3))	return;
 
 	if (strchr(filename, 'D'))
 	{
@@ -599,7 +578,7 @@ int	rc;
 		sleep(3);
 	}
 
-	strcpy(uniqbuf, ":2,");
+	strcpy(uniqbuf, MDIRSEP "2,");
 	append_flags(uniqbuf, flags);
 
 	if (uniqbuf[3] == 0 &&	/* No flags, messages goes into new */
@@ -632,7 +611,6 @@ char	*newname;
 char	*p;
 FILE	*fp;
 unsigned long n;
-char	quotabuf[QUOTABUFSIZE];
 int	fd;
 static const char nowrite[]=" NO [ALERT] Cannot create message - no write permission or out of disk space.\r\n";
 int	rc;
@@ -736,14 +714,14 @@ int	lastnl;
 	}
 #endif
 #endif
-	if (!is_trash(mailbox) && maildir_getquota(mailbox, quotabuf) == 0)
+	if (maildirquota_countfolder(mailbox) &&
+	    maildirquota_countfile(p))
 	{
-	int	quotafd;
+		struct maildirsize quotainfo;
 
-		if (maildir_checkquota(mailbox, &quotafd, quotabuf, nbytes, 1)
-			&& errno != EAGAIN)
+		if (maildir_quota_add_start(mailbox, &quotainfo, nbytes, 1,
+					    NULL))
 		{
-			if (quotafd >= 0)	close(quotafd);
 			unlink(tmpname);
 			free(tmpname);
 			free(p);
@@ -751,11 +729,23 @@ int	lastnl;
 			writes(" NO [ALERT] You exceeded your mail quota.\r\n");
 			return (-1);
 		}
-		maildir_addquota(mailbox, quotafd, quotabuf, nbytes, 1);
-		if (quotafd >= 0)	close(quotafd);
+		maildir_quota_add_end(&quotainfo, nbytes, 1);
 	}
 
-	rc=rename(tmpname, p);
+	if (check_outbox(tmpname, mailbox))
+	{
+		unlink(tmpname);
+		writes(tag);
+		writes(" NO [ALERT] Unable to send E-mail message.\r\n");
+		free(tmpname);
+		free(p);
+		return (-1);
+	}
+
+	if (autodelete_outbox(tmpname, mailbox))
+		rc=0;
+	else
+		rc=rename(tmpname, p);
 	if (rc)
 	{
 		writes(tag);
@@ -1098,6 +1088,7 @@ unsigned long j;
 struct imapflags flags;
 char	*old_name;
 int	move_to_trash=0;
+struct stat stat_buf;
 
 	fetch_free_cache();
 
@@ -1107,6 +1098,8 @@ int	move_to_trash=0;
 
 	for (j=0; j < current_mailbox_info.nmessages; j++)
 	{
+		int file_counted=0;
+
 		get_message_flags(current_mailbox_info.msgs+j, 0, &flags);
 
 		if (!flags.deleted)
@@ -1115,6 +1108,10 @@ int	move_to_trash=0;
 		old_name=alloc_filename(current_mailbox,
 			current_mailbox_info.msgs[j].filename);
 
+		if (maildirquota_countfolder(current_mailbox) &&
+		    maildirquota_countfile(old_name))
+			file_counted=1;
+
 		if (is_sharedsubdir(current_mailbox))
 		{
 			maildir_unlinksharedmsg(old_name);
@@ -1123,15 +1120,39 @@ int	move_to_trash=0;
 		{
 		char	*new_name;
 		char	*p;
+		int will_count=0;
 
 			new_name=alloc_filename("." TRASH,
 				current_mailbox_info.msgs[j].filename);
 
+			if (maildirquota_countfolder("." TRASH))
+				will_count=1;
+
+			if (file_counted != will_count)
+			{
+				unsigned long filesize=0;
+
+				if (maildir_parsequota(old_name, &filesize))
+				{
+					if (stat(old_name, &stat_buf))
+						stat_buf.st_size=0;
+					filesize=(unsigned long)
+						stat_buf.st_size;
+				}
+
+				maildir_quota_deleted(".",
+						      (long)filesize *
+						      (will_count
+						       -file_counted),
+						      will_count
+						      -file_counted);
+			}
+
 			/* Don't mark it as deleted in the Trash */
 
 			if ((p=strrchr(new_name, '/')) &&
-				(p=strrchr(p, ':')) &&
-				strncmp(p, ":2,", 3) == 0 &&
+				(p=strrchr(p, MDIRSEP[0])) &&
+				strncmp(p, MDIRSEP "2,", 3) == 0 &&
 				(p=strchr(p, 'T')))
 				while ((*p=p[1]) != 0)
 					++p;
@@ -1145,6 +1166,21 @@ int	move_to_trash=0;
 		else
 		{
 			unlink(old_name);
+
+			if (file_counted)
+			{
+				unsigned long filesize=0;
+
+				if (maildir_parsequota(old_name, &filesize))
+				{
+					if (stat(old_name, &stat_buf))
+						stat_buf.st_size=0;
+					filesize=(unsigned long)
+						stat_buf.st_size;
+				}
+
+				maildir_quota_deleted(".",-(long)filesize, -1);
+			}
 		}
 		free(old_name);
 	}
@@ -1354,6 +1390,12 @@ static int do_rename(const char *on, const char *nn)
 
 static int do_rename(const char *, const char *);
 
+static int do_count(unsigned long n, int byuid, void *voidptr)
+{
+	++ *(int *)voidptr;
+	return 0;
+}
+
 int do_imap_command(const char *tag)
 {
 struct	imaptoken *curtoken=nexttoken();
@@ -1755,8 +1797,8 @@ int	uid=0;
 			{
 			const char *p=infoptr->msgs[i].filename;
 
-				p=strrchr(p, ':');
-				if (p && strncmp(p, ":2,", 3) == 0 &&
+				p=strrchr(p, MDIRSEP[0]);
+				if (p && strncmp(p, MDIRSEP "2,", 3) == 0 &&
 					strchr(p, 'S'))	continue;
 				++n;
 			}
@@ -2685,10 +2727,10 @@ int	uid=0;
 
 	if (strcmp(curtoken->tokenbuf, "COPY") == 0)
 	{
+	struct maildirsize quotainfo;
 	char	*mailbox;
 	char	*msgset;
 	struct copyquotainfo cqinfo;
-	char	quotabuf[QUOTABUFSIZE];
 	int	has_quota;
 	int	isshared;
 
@@ -2769,22 +2811,30 @@ int	uid=0;
 		cqinfo.nfiles=0;
 
 		has_quota=0;
-		if (!isshared && maildir_getquota(mailbox, quotabuf) == 0)
+		if (!isshared && maildirquota_countfolder(cqinfo.destmailbox))
 		{
-			has_quota=1;
-			if (do_msgset(msgset, &do_copy_quota_calc, &cqinfo,
-					uid))
+			if (maildir_openquotafile(&quotainfo,
+						  ".") == 0)
+			{
+				if (quotainfo.fd >= 0)
+					has_quota=1;
+				maildir_closequotafile(&quotainfo);
+			}
+
+			if (has_quota > 0 &&
+			    do_msgset(msgset, &do_copy_quota_calc, &cqinfo,
+				      uid))
 				has_quota= -1;
 		}
+
 		if (has_quota > 0 && cqinfo.nfiles > 0)
 		{
-		int	quotafd;
 
-			if (maildir_checkquota(mailbox, &quotafd,
-				quotabuf, cqinfo.nbytes, cqinfo.nfiles)
-				&& errno != EAGAIN)
+			if (maildir_quota_add_start(".", &quotainfo,
+						    cqinfo.nbytes,
+						    cqinfo.nfiles,
+						    NULL))
 			{
-				if (quotafd >= 0)	close(quotafd);
 				writes(tag);
 				writes(
 			" NO [ALERT] You exceeded your mail quota.\r\n");
@@ -2793,9 +2843,24 @@ int	uid=0;
 				return (0);
 			}
 
-			maildir_addquota(mailbox, quotafd, quotabuf,
-				cqinfo.nbytes, cqinfo.nfiles);
-			if (quotafd >= 0)	close(quotafd);
+			maildir_quota_add_end(&quotainfo,
+					      cqinfo.nbytes,
+					      cqinfo.nfiles);
+		}
+
+		if (is_outbox(mailbox))
+		{
+			int counter=0;
+
+			if (do_msgset(msgset, &do_count, &counter, uid) ||
+			    counter > 1)
+			{
+				writes(tag);
+				writes(" NO [ALERT] Only one message may be sent at a time.\r\n");
+				free(msgset);
+				free(mailbox);
+				return (0);
+			}
 		}
 
 		if (has_quota < 0 ||
@@ -2803,6 +2868,8 @@ int	uid=0;
 		{
 			writes(tag);
 			writes(" NO [ALERT] COPY failed - no write permission or out of disk space.\r\n");
+			free(msgset);
+			free(mailbox);
 			return (0);
 		}
 
@@ -2944,7 +3011,10 @@ const char *tag;
 	imapscanpath=getimapscanpath(argv[0]);
 #endif
 	if (p && *p && chdir(p))
+	{
+		fprintf(stderr, "chdir %s: %s\n", p, strerror(errno));
 		write_error_exit(p);
+	}
 
 	p=getenv("HOSTNAME");
 	if (!p)
