@@ -1,5 +1,5 @@
 /*
-** Copyright 1998 - 2001 Double Precision, Inc.
+** Copyright 1998 - 2002 Double Precision, Inc.
 ** See COPYING for distribution information.
 */
 
@@ -47,6 +47,7 @@
 
 #include	"liblock/config.h"
 #include	"liblock/liblock.h"
+#include	"maildir/config.h"
 #include	"maildir/maildircreate.h"
 #include	"maildir/maildirmisc.h"
 
@@ -55,7 +56,7 @@
 #include	"imapwrite.h"
 #include	"imapd.h"
 
-static const char rcsid[]="$Id: imapscanclient.c,v 1.16 2001/11/03 15:44:43 mrsam Exp $";
+static const char rcsid[]="$Id: imapscanclient.c,v 1.19 2002/07/02 20:01:37 mrsam Exp $";
 
 static int do_imapscan_maildir2(struct imapscaninfo *, const char *, int, int);
 
@@ -331,6 +332,11 @@ int	dowritecache=0;
 		uidv=stat_buf.st_mtime;
 		dowritecache=1;
 	}
+	else
+	{
+		nextuid=1;
+		time(&uidv);
+	}
 
 	if (!fp && (fp=fopen(newdbfilepath, "w")) == 0)
 	{
@@ -391,10 +397,10 @@ int	dowritecache=0;
 		p=my_strdup(de->d_name);
 
 		/* IMAPDB doesn't store the filename flags, so strip them */
-		q=strrchr(p, ':');
+		q=strrchr(p, MDIRSEP[0]);
 		if (q)	*q=0;
 		rc=search_by_filename(tempinfo_array, tempinfo_cnt, &i, p);
-		if (q)	*q=':';
+		if (q)	*q=MDIRSEP[0];
 		if (rc == 0)
 		{
 			tempinfo_array[i]->found=1;
@@ -470,7 +476,7 @@ int	dowritecache=0;
 		z=de->d_name;
 
 		newname=imapscan_namedir(p, z);
-		curname=malloc(strlen(newname)+sizeof(":2,"));
+		curname=malloc(strlen(newname)+sizeof(MDIRSEP "2,"));
 		if (!curname)
 		{
 			unlink(newdbfilepath);
@@ -480,8 +486,8 @@ int	dowritecache=0;
 		z=strrchr(curname, '/');
 
 		memcpy(z-3, "cur", 3); /* Mother of all hacks */
-		if (strchr(z, ':') == 0)
-			strcat(z, ":2,");
+		if (strchr(z, MDIRSEP[0]) == 0)
+			strcat(z, MDIRSEP "2,");
 
 		if (rename(newname, curname))
 		{
@@ -552,11 +558,11 @@ int	dowritecache=0;
 
 		for (i=0; i<tempinfo_cnt; i++)
 		{
-			q=strrchr(tempinfo_array[i]->filename, ':');
+			q=strrchr(tempinfo_array[i]->filename, MDIRSEP[0]);
 			if (q)	*q=0;
 			fprintf(fp, "%lu %s\n", tempinfo_array[i]->uid,
 				tempinfo_array[i]->filename);
-			if (q)	*q=':';
+			if (q)	*q=MDIRSEP[0];
 		}
 		if (fflush(fp) || ferror(fp) || fclose(fp))
 		{
@@ -603,7 +609,7 @@ int	dowritecache=0;
 	scaninfo->nmessages=tempinfo_cnt;
 	scaninfo->uidv=uidv;
 	scaninfo->left_unseen=left_unseen;
-	scaninfo->nextuid=nextuid;
+	scaninfo->nextuid=nextuid+left_unseen;
 
 	for (i=0; i<tempinfo_cnt; i++)
 	{
