@@ -28,7 +28,7 @@
 #include	"imaptoken.h"
 #include	"imapscanclient.h"
 
-static const char rcsid[]="$Id: search.c,v 1.18 2001/08/31 01:39:49 mrsam Exp $";
+static const char rcsid[]="$Id: search.c,v 1.20 2002/07/07 21:30:02 mrsam Exp $";
 
 extern time_t rfc822_parsedt(const char *);
 extern struct imapscaninfo current_mailbox_info;
@@ -533,6 +533,7 @@ static void fill_search_header(struct searchinfo *si,
 	int	isdate;
 	char *conv_buf;
 	char *conv_buf_uc;
+	const struct unicode_info *search_chset;
 
 		/* Collect multiline header into the readline buffer */
 
@@ -562,7 +563,12 @@ static void fill_search_header(struct searchinfo *si,
 		while (*r && isspace((int)(unsigned char)*r))
 			++r;
 
-		conv_buf=rfc2047_decode_unicode(r, mycharset,
+		search_chset=mycharset;
+
+		if (search_chset->search_chset)
+			search_chset=search_chset->search_chset;
+
+		conv_buf=rfc2047_decode_unicode(r, search_chset,
 						RFC2047_DECODE_DISCARD);
 
 			/* Characters not in our charset are discarded */
@@ -570,7 +576,7 @@ static void fill_search_header(struct searchinfo *si,
 		if (!conv_buf && errno != EINVAL)
 			write_error_exit(0);
 
-		conv_buf_uc= (*mycharset->toupper_func)(conv_buf, 0);
+		conv_buf_uc= (*search_chset->toupper_func)(conv_buf, 0);
 		if (!conv_buf_uc)
 			write_error_exit(0);
 
@@ -696,7 +702,7 @@ static void fill_search_header(struct searchinfo *si,
 			if (sip->type == search_references1 &&
 			    strcmp(p, "REFERENCES") == 0 && sip->as == 0)
 			{
-				sip->as=strdup(q);
+				sip->as=strdup(conv_buf);
 				if (!sip->as)
 					write_error_exit(0);
 			}
@@ -710,7 +716,7 @@ static void fill_search_header(struct searchinfo *si,
 				struct rfc822a *a;
 				char *s;
 
-				t=rfc822t_alloc_new(q, NULL, NULL);
+				t=rfc822t_alloc_new(conv_buf, NULL, NULL);
 				if (!t) write_error_exit(0);
 				a=rfc822a_alloc(t);
 				if (!a) write_error_exit(0);
@@ -928,6 +934,7 @@ static int search_body_func(const char *ptr, size_t cnt, void *voidptr)
 	{
 		char c=ptr[i];
 		char *p;
+		const struct unicode_info *uc_info;
 
 		if (c != '\n' && c != '\r')
 		{
@@ -937,7 +944,26 @@ static int search_body_func(const char *ptr, size_t cnt, void *voidptr)
 		}
 		slb->buf[slb->l]=0;
 
-		p=(*slb->uc->toupper_func)(slb->buf, 0);
+		uc_info=slb->uc;
+
+		if (uc_info->search_chset)
+		{
+			char *q;
+
+			p=unicode_convert(slb->buf, uc_info,
+					  uc_info->search_chset);
+
+			if (p)
+			{
+				uc_info=uc_info->search_chset;
+				q=(uc_info->toupper_func)(p, 0);
+				free(p);
+				p=q;
+			}
+
+		}
+		else
+			p=(*uc_info->toupper_func)(slb->buf, 0);
 		if (!p)
 			write_error_exit(0);
 
