@@ -1,5 +1,5 @@
 /*
-** Copyright 1998 - 2001 Double Precision, Inc.
+** Copyright 1998 - 2002 Double Precision, Inc.
 ** See COPYING for distribution information.
 */
 
@@ -16,6 +16,7 @@
 #include	"storeinfo.h"
 #include	"maildir/maildirquota.h"
 #include	"maildir/maildirmisc.h"
+#include	"outbox.h"
 
 #include	<stdio.h>
 #include	<stdlib.h>
@@ -37,7 +38,7 @@
 #endif
 #endif
 
-static const char rcsid[]="$Id: storeinfo.c,v 1.9 2001/11/14 04:14:24 mrsam Exp $";
+static const char rcsid[]="$Id: storeinfo.c,v 1.11 2002/06/10 14:27:37 mrsam Exp $";
 
 extern int is_trash(const char *);
 extern int get_flagname(const char *, struct imapflags *);
@@ -231,7 +232,17 @@ int	rc;
 #endif
 #endif
 
-	if ((rc=rename(tmpname, newname)) != 0)
+	if (check_outbox(tmpname, mailbox))
+	{
+		unlink(tmpname);
+		free(tmpname);
+		free(newname);
+		return (-1);
+	}
+
+	if (autodelete_outbox(tmpname, mailbox))
+		rc=0;
+	else if ((rc=rename(tmpname, newname)) != 0)
 		unlink(tmpname);
 
 	free(tmpname);
@@ -268,8 +279,6 @@ struct	stat	stat_buf;
 int	fd;
 
 	--n;
-	if (is_trash(info->destmailbox))
-		return (0);	/* No problems dumping everything into trash */
 
 	fd=imapscan_openfile(current_mailbox, &current_mailbox_info, n);
 	if (fd < 0)	return (0);
