@@ -1,9 +1,9 @@
 /*
-** Copyright 2000 Double Precision, Inc.
+** Copyright 2000-2002 Double Precision, Inc.
 ** See COPYING for distribution information.
 */
 
-static const char rcsid[]="$Id: thread.c,v 1.7 2002/01/19 02:44:58 mrsam Exp $";
+static const char rcsid[]="$Id: thread.c,v 1.8 2002/06/10 00:43:23 mrsam Exp $";
 
 #include	"config.h"
 #include	"imapd.h"
@@ -25,6 +25,7 @@ static void thread_ref_callback(struct searchinfo *, struct searchinfo *, int,
 
 extern struct imapscaninfo current_mailbox_info;
 
+
 struct os_threadinfo {
 	struct os_threadinfo *next;
 	char *subj;
@@ -32,6 +33,11 @@ struct os_threadinfo {
 	unsigned long n;
 	} ;
 
+struct os_threadinfo_list {
+	struct os_threadinfo_list *next;
+	size_t thread_start;
+} ;
+
 struct os_struct {
 	struct os_threadinfo *list;
 	unsigned nmsgs;
@@ -89,14 +95,46 @@ static int cmpsubjs(const void *a, const void *b)
 
 static void printos(struct os_threadinfo **array, size_t cnt)
 {
-size_t	i;
+	size_t	i;
+	struct os_threadinfo_list *thread_list=NULL, *threadptr, **tptr;
 
-	/* The array is already sorted */
+	/*
+	** thread_list - indexes to start of each thread, sort indexes by
+	** sent_date
+	*/
 
-	for (i=0; i<cnt; )
+	for (i=0; i<cnt; i++)
 	{
-	size_t	j;
-	const char *p;
+		/* Find start of next thread */
+
+		if (i > 0 && strcmp(array[i-1]->subj, array[i]->subj) == 0)
+			continue;
+
+		threadptr=malloc(sizeof(struct os_threadinfo_list));
+		if (!threadptr)
+			write_error_exit(0);
+		threadptr->thread_start=i;
+
+		/* Insert into the list, sorted by sent date */
+
+		for (tptr= &thread_list; *tptr; tptr=&(*tptr)->next)
+			if ( array[(*tptr)->thread_start]->sent_date
+			     > array[i]->sent_date)
+				break;
+
+		threadptr->next= *tptr;
+		*tptr=threadptr;
+	}
+
+	while ( (threadptr=thread_list) != NULL)
+	{
+		size_t	i, j;
+		const char *p;
+
+		thread_list=threadptr->next;
+
+		i=threadptr->thread_start;
+		free(threadptr);
 
 		for (j=i+1; j<cnt; j++)
 		{
