@@ -1,5 +1,5 @@
 /*
-** Copyright 2000 Double Precision, Inc.  See COPYING for
+** Copyright 2000-2001 Double Precision, Inc.  See COPYING for
 ** distribution information.
 */
 
@@ -29,10 +29,14 @@
 #include	<sys/ioctl.h>
 #endif
 
-static const char rcsid[]="$Id: lockdaemon.c,v 1.2 2000/11/04 19:01:25 mrsam Exp $";
+#define exit(_a_) _exit(_a_)
+
+static const char rcsid[]="$Id: lockdaemon.c,v 1.6 2002/04/01 19:59:34 mrsam Exp $";
 
 static int start1(const char *, int);
 
+#define CONSOLE "/dev/null"
+
 int ll_daemon_start(const char *lockfile)
 {
 pid_t	p;
@@ -168,12 +172,12 @@ int	i;
 		return (-1);
 
 	close(1);
-	i=open("/dev/console", O_WRONLY);
+	i=open(CONSOLE, O_WRONLY);
 	if (i < 0)	i=open("/dev/null", O_WRONLY);
 	if (i != 1)	return (-1);
 
 	close(2);
-	i=open("/dev/console", O_WRONLY);
+	i=open(CONSOLE, O_WRONLY);
 	if (i < 0)	i=open("/dev/null", O_WRONLY);
 	if (i != 2)	return (-1);
 	return (0);
@@ -186,7 +190,7 @@ char	*p=strcat(str_pid_t(getpid(), buf), "\n");
 size_t	l=strlen(p);
 FILE	*fp;
 
-	if ((fp=fopen(pidfile, "w")) < 0 ||
+	if ((fp=fopen(pidfile, "w")) == NULL ||
 		fprintf(fp, "%s", p) < 0 || fflush(fp) < 0 || fclose(fp))
 	{
 		perror(pidfile);
@@ -277,7 +281,7 @@ pid_t	p;
 		FILE	*fp;
 		int	c;
 
-			if ((fp=fopen(pidfile, "r")) < 0)
+			if ((fp=fopen(pidfile, "r")) == NULL)
 				continue;
 
 			p=0;
@@ -321,7 +325,7 @@ int	c;
 	}
 	close(lockfd);
 
-	if ((fp=fopen(pidfile, "r")) < 0)
+	if ((fp=fopen(pidfile, "r")) == NULL)
 		return (0);
 
 	p=0;
