@@ -3,10 +3,16 @@
 ** See COPYING for distribution information.
 */
 
-/* $Id: acconfig.h,v 1.3 2000/02/14 05:11:39 mrsam Exp $ */
+/* $Id: acconfig.h,v 1.5 2002/07/02 20:01:37 mrsam Exp $ */
 
 /* Whether gethostname() is prototyped */
 #undef	HAS_GETHOSTNAME
 
 /* Whether top-level configure defined dbobj struct/.h */
 #undef	HAVE_DBOBJ
+
+/* Whether to count messages marked as deleted, and messages in the Trash folder as part of the quota */
+#undef	TRASHQUOTA
+
+/* Maildir filename separator character (usually :) */
+#undef	MDIRSEP
