@@ -3,7 +3,7 @@
 ** See COPYING for distribution information.
 */
 
-/* $Id: maildirmake.c,v 1.5 2000/05/07 17:14:24 mrsam Exp $ */
+/* $Id: maildirmake.c,v 1.7 2002/06/10 00:33:55 mrsam Exp $ */
 
 #if	HAVE_CONFIG_H
 #include	"config.h"
@@ -26,6 +26,7 @@
 #include	"maildircreate.h"
 #include	"maildirmisc.h"
 #include	"maildirsharedrc.h"
+#include	"maildirquota.h"
 
 static void usage()
 {
@@ -99,6 +100,12 @@ char	*ptr, *dirp;
 		exit(1);
 	}
 
+	if (fseek(fp, 0L, SEEK_SET) < 0)
+	{
+		perror(dir);
+		exit(1);
+	}
+
 	while ((ptr=fgets(buf, sizeof(buf), fp)) != 0)
 	{
 	char	*namep;
@@ -213,6 +220,7 @@ int	perm=0700;
 int	musthavefolder=0;
 int	subdirperm;
 char	*addshared=0, *delshared=0;
+const char *quota=0;
 
 	for (argn=1; argn<argc; argn++)
 	{
@@ -260,6 +268,17 @@ char	*addshared=0, *delshared=0;
 			continue;
 		}
 
+		if (strncmp(argv[argn], "-q", 2) == 0)
+		{
+			const char *p=argv[argn]+2;
+
+			if (*p == 0 && argn+1 < argc)
+				p=argv[++argn];
+
+			quota=p;
+			continue;
+		}
+
 		if (strcmp(argv[argn], "--add") == 0 && argc-argn > 1)
 		{
 			addshared=argv[++argn];
@@ -310,6 +329,11 @@ char	*addshared=0, *delshared=0;
 	else	if (musthavefolder)
 		usage();
 
+	if (quota)
+	{
+		maildir_quota_set(maildir, quota);
+		exit(0);
+	}
 	subdirperm=perm;
 	if (!folder)	subdirperm=0700;
 	umask(0);
