@@ -1,5 +1,5 @@
 /*
-** Copyright 2000 Double Precision, Inc.
+** Copyright 2000-2002 Double Precision, Inc.
 ** See COPYING for distribution information.
 */
 
@@ -41,7 +41,7 @@
 #include	"maildircreate.h"
 #include	"maildirsharedrc.h"
 
-static const char rcsid[]="$Id: maildirshared.c,v 1.14 2001/04/05 03:27:11 mrsam Exp $";
+static const char rcsid[]="$Id: maildirshared.c,v 1.16 2002/07/02 20:01:37 mrsam Exp $";
 
 /* Prerequisited for shared folder support */
 
@@ -175,7 +175,7 @@ int	pass;
 
 			if (!n)	continue;
 
-			if (strlen(n) == name - folder ||
+			if (strlen(n) == name - folder &&
 				memcmp(n, folder, name-folder) == 0)	break;
 		}
 		fclose(fp);
@@ -487,7 +487,7 @@ struct	dirent *de;
 		}
 		strcpy(a, de->d_name);
 		strcpy(b, de->d_name);
-		c=strrchr(a, ':');
+		c=strrchr(a, MDIRSEP[0]);
 		if (c)	*c=0;
 
 		if (dbobj_store(obj, a, strlen(a), b, strlen(b), "R"))
@@ -553,7 +553,7 @@ char	*p;
 			return (-1);
 		}
 		strcpy(cur_base, de->d_name);
-		p=strrchr(cur_base, ':');
+		p=strrchr(cur_base, MDIRSEP[0]);
 		if (p)	*p=0;
 
 		cur_name_ptr=dbobj_fetch(obj, cur_base, strlen(cur_base),
@@ -754,7 +754,7 @@ char	*tmpname, *dummy;
 		}
 
 		free(slink);
-		slink=malloc(strlen(cur)+sizeof("/new/:2,")+keylen);
+		slink=malloc(strlen(cur)+sizeof("/new/" MDIRSEP "2,")+keylen);
 		if (!slink)
 		{
 			perror("malloc");
@@ -764,7 +764,7 @@ char	*tmpname, *dummy;
 		strcat(strcpy(slink, cur), "/new/");
 		q=slink+strlen(slink);
 		memcpy(q, key, keylen);
-		strcpy(q+keylen, ":2,");
+		strcpy(q+keylen, MDIRSEP "2,");
 
 		if (rename(tmpname, slink))
 		{
@@ -900,10 +900,10 @@ char	*buf=maildir_getlink(filename);
 
 			if (cpy)
 			{
-				char *p=strrchr(cpy, ':');
+				char *p=strrchr(cpy, MDIRSEP[0]);
 
 				if (p && strchr(p, '/') == 0 &&
-				    strncmp(p, ":2,", 3) == 0 &&
+				    strncmp(p, MDIRSEP "2,", 3) == 0 &&
 				    (p=strchr(p, 'T')) != 0)
 				{
 					while ((*p=p[1]) != 0)
