@@ -1,5 +1,5 @@
 /*
-** Copyright 1998 - 2000 Double Precision, Inc.
+** Copyright 1998 - 2001 Double Precision, Inc.
 ** See COPYING for distribution information.
 */
 
@@ -30,7 +30,7 @@
 #include	"rfc1035.h"
 
 
-static const char rcsid[]="$Id: rfc1035.c,v 1.7 2000/05/28 17:46:00 mrsam Exp $";
+static const char rcsid[]="$Id: rfc1035.c,v 1.9 2002/07/01 03:17:05 mrsam Exp $";
 
 void rfc1035_init_timeout(struct rfc1035_res *res, unsigned s, unsigned n)
 {
@@ -42,13 +42,12 @@ void rfc1035_init_ns(struct rfc1035_res *res, const RFC1035_ADDR *a, unsigned n)
 {
 unsigned i;
 unsigned j;
-struct timeval	tv;
-struct timezone tz;
 
 	j=0;
 
-	gettimeofday(&tv, &tz);
-	res->id=(unsigned) (tv.tv_sec ^ tv.tv_usec ^ getpid());
+	random128_binary(&res->randseed);
+	md5_digest(&res->randseed, sizeof(res->randseed), res->randbuf);
+	res->randptr=0;
 
 	for (i=0; i == 0 || (i<n && i<MAXNS); i++)
 	{
@@ -160,6 +159,27 @@ static int mkpacketq(void (*)(const char *, unsigned, void *), void *,
 		struct compresslist *,
 		struct rfc1035_res *);
 
+unsigned rfc1035_next_randid(struct rfc1035_res *res)
+{
+	unsigned i;
+
+	if (res->randptr >= sizeof(res->randbuf))
+	{
+		for (i=0; i<sizeof(res->randseed); i++)
+			if ( ++((unsigned char *)res->randseed)[i])
+				break;
+
+		md5_digest(res->randseed, sizeof(res->randseed),
+			   res->randbuf);
+		res->randptr=0;
+	}
+
+	i= ((unsigned)((unsigned char *)res->randbuf)[res->randptr] << 8) |
+		((unsigned char *)res->randbuf)[res->randptr+1];
+	res->randptr += 2;
+	return i;
+}
+
 int rfc1035_mkquery(struct rfc1035_res *res,	/* resolver */
 			unsigned opcode,	/* opcode */
 			int options,		/* various options */
@@ -177,11 +197,12 @@ struct {
 	} header;
 unsigned cnt;
 
-	header.idhi= res->id >> 8;
-	header.idlo= res->id;
-	++res->id;
+	unsigned id=rfc1035_next_randid(res);
 
-	header.infohi= (opcode << 4) & 0x70;
+	header.idhi= id >> 8;
+	header.idlo= id;
+
+	header.infohi= (opcode << 3) & 0x78;
 	if (options & RFC1035_RESOLVE_RECURSIVE)
 		header.infohi |= 1;
 	header.infolo=0;
