@@ -1,5 +1,5 @@
 /*
-** Copyright 1998 - 2000 Double Precision, Inc.  See COPYING for
+** Copyright 1998 - 2002 Double Precision, Inc.  See COPYING for
 ** distribution information.
 */
 
@@ -26,6 +26,7 @@
 #include	<fcntl.h>
 #include	<signal.h>
 #include	"rfc2045.h"
+#include	"rfc822/rfc822.h"
 #include	"rfc822/rfc2047.h"
 #include	"rfc2045charset.h"
 #if HAVE_UNISTD_H
@@ -41,8 +42,9 @@
 int gethostname(const char *, size_t);
 #endif
 
+extern int rfc2045_in_reformime;
 
-static const char rcsid[]="$Id: reformime.c,v 1.33 2000/12/16 20:55:35 mrsam Exp $";
+static const char rcsid[]="$Id: reformime.c,v 1.40 2002/03/19 01:29:18 mrsam Exp $";
 
 void rfc2045_error(const char *errmsg)
 {
@@ -69,7 +71,7 @@ FILE	*fp=(FILE *)ptr;
 	while (n)
 	{
 		--n;
-		if (putc(*p++, fp) == -1)
+		if (putc((int)(unsigned char)*p++, fp) == EOF)
 		{
 			perror("write");
 			exit(1);
@@ -121,6 +123,7 @@ struct rfc2045 *read_message()
 char	buf[BUFSIZ];
 struct	rfc2045 *p=rfc2045_alloc_ac();
 FILE	*tempfp=0;
+int	l;
 
 	if (fseek(stdin, 0L, SEEK_END) < 0 ||
 		fseek(stdin, 0L, SEEK_SET) < 0)	/* Pipe, save to temp file */
@@ -128,9 +131,8 @@ FILE	*tempfp=0;
 		tempfp=tmpfile();
 	}
 
-	while (fgets(buf, sizeof(buf), stdin))
+	while ((l=fread(buf, 1, sizeof(buf), stdin)) > 0)
 	{
-	int l=strlen(buf);
 
 		rfc2045_parse(p, buf, l);
 		if (tempfp && fwrite(buf, l, 1, tempfp) != 1)
@@ -366,6 +368,24 @@ char	*dyn_disp_name=0;
 			;
 	}
 
+	/* Strip leading/trailing spaces */
+
+	p=filename_buf;
+	while (*p && isspace((int)(unsigned char)*p))
+		++p;
+
+	q=filename_buf;
+	while ((*q=*p) != 0)
+	{
+		++p;
+		++q;
+	}
+
+	for (p=q=filename_buf; *p; p++)
+		if (!isspace((int)(unsigned char)*p))
+			q=p+1;
+	*q=0;
+
 	disposition_filename_s=filename_buf;
 
 	if (ignore_filename)
@@ -877,15 +897,23 @@ char	optc;
 char	*optarg;
 char	*mimesection=0;
 int	doinfo=0, dodecode=0, dorewrite=0, dodsn=0, domimedigest=0;
+int	dodecodehdr=0, doencodemime=0, doencodemimehdr=0;
+
+char	*decode_header="";
+ char	*mimecharset="iso-8859-1";
 struct	rfc2045 *p;
 int	rwmode=0;
+int	dovalidate=0;
 void	(*do_extract)(struct rfc2045 *, const char *, int, char **)=0;
 const char *extract_filename=0;
+int rc=0;
 
 #if HAVE_SETLOCALE
 	setlocale(LC_ALL, "C");
 #endif
 
+	rfc2045_in_reformime=1;
+
 	for (argn=1; argn<argc; )
 	{
 		if (argv[argn][0] != '-')	break;
@@ -898,7 +926,10 @@ const char *extract_filename=0;
 			if (!optarg && argn < argc)
 				optarg=argv[argn++];
 			if (optarg && *optarg)
+			{
+				mimecharset=optarg;
 				rfc2045_setdefaultcharset(optarg);
+			}
 			break;
 
 		case 's':
@@ -939,6 +970,37 @@ const char *extract_filename=0;
 		case 'v':
 			printf("%s\n", rcsid);
 			exit(0);
+		case 'V':
+			dovalidate=1;
+			break;
+		case 'h':
+			if (!optarg && argn < argc)
+				optarg=argv[argn++];
+			if (optarg)
+			{
+				decode_header=optarg;
+			}
+			dodecodehdr=1;
+			break;
+		case 'o':
+			if (!optarg && argn < argc)
+				optarg=argv[argn++];
+			if (optarg)
+			{
+				decode_header=optarg;
+			}
+			doencodemime=1;
+			break;
+		case 'O':
+			if (!optarg && argn < argc)
+				optarg=argv[argn++];
+			if (optarg)
+			{
+				decode_header=optarg;
+			}
+			doencodemimehdr=1;
+			break;
+
 		default:
 			usage();
 		}
@@ -949,11 +1011,54 @@ const char *extract_filename=0;
 		mimedigest(argc-argn, argv+argn);
 		return (0);
 	}
+	else if (dodecodehdr)
+	{
+		char *s=rfc2047_decode_simple(decode_header);
+
+		if (s)
+		{
+			printf("%s\n", s);
+			free(s);
+		}
+		return (0);
+	}
+	if (doencodemime)
+	{
+		char *s=rfc2047_encode_str(decode_header, mimecharset);
+
+		if (s)
+		{
+			printf("%s\n", s);
+			free(s);
+		}
+		return (0);
+	}
+	if (doencodemimehdr)
+	{
+		struct rfc822t *t=rfc822t_alloc_new(decode_header, NULL, NULL);
+		struct rfc822a *a=t ? rfc822a_alloc(t):NULL;
+		char *s;
+
+		if (a && (s=rfc2047_encode_header(a, mimecharset)) != NULL)
+		{
+			printf("%s\n", s);
+			free(s);
+		}
+
+		if (a) rfc822a_free(a);
+		if (t) rfc822t_free(t);
+		return (0);
+	}
 
 	p=read_message();
 
 	if (doinfo)
+	{
 		print_info(p, mimesection);
+		if (do_extract)
+			extract_section(p, mimesection, extract_filename,
+					argc-argn, argv+argn, do_extract);
+	}
 	else if (dodecode)
 		print_decode(p, mimesection);
 	else if (dorewrite)
@@ -963,9 +1068,24 @@ const char *extract_filename=0;
 	else if (do_extract)
 		extract_section(p, mimesection, extract_filename,
 			argc-argn, argv+argn, do_extract);
+	else if (dovalidate)
+	{
+		rc=1;
+
+		if (p->rfcviolation & RFC2045_ERR8BITHEADER)
+			printf("ERROR: Illegal 8-bit header.\n");
+		else if (p->rfcviolation & RFC2045_ERR8BITCONTENT)
+			printf("ERROR: Illegal 8-bit content.\n");
+		else if (p->rfcviolation & RFC2045_ERR2COMPLEX)
+			printf("ERROR: MIME complexity.\n");
+		else if (p->rfcviolation & RFC2045_ERRBADBOUNDARY)
+			printf("ERROR: Ambiguous  MIME boundary delimiters.\n");
+		else rc=0;
+
+	}
 	else
 		print_structure(p);
 	rfc2045_free(p);
-	exit(0);
-	return (0);
+	exit(rc);
+	return (rc);
 }
