@@ -50,13 +50,12 @@
 #include	"liblock/config.h"
 #include	"liblock/liblock.h"
 #include	"tcpremoteinfo.h"
-#include	"authlib/auth.h"
 #include	"numlib/numlib.h"
 #include	"argparse.h"
 
 #include	<netdb.h>
 
-static const char rcsid[]="$Id: tcpd.c,v 1.27 2001/11/22 15:29:38 mrsam Exp $";
+static const char rcsid[]="$Id: tcpd.c,v 1.32 2002/08/01 15:58:21 mrsam Exp $";
 
 static const char *accessarg=0;
 static const char *listenarg=0;
@@ -193,6 +192,8 @@ static RETSIGTYPE sighup(int n)
 {
 	sighup_received=1;
 
+	signal(SIGHUP, sighup);
+
 #if RETSIGTYPE != void
 	return (0)
 #endif
@@ -865,6 +866,7 @@ int	l;
 		}
 		*accessptr=0;
 	}
+
 	if (strncmp(accessptr, "deny", 4) == 0)
 	{
 		free(accessptr);
@@ -917,7 +919,8 @@ int	l;
 		}
 
 		while (*q && isspace((int)(unsigned char)*q))	++q;
-		while (l=strlen(q)-1, isspace((int)(unsigned char)q[l-1]))
+		while ((l=strlen(q)) > 0
+		       && isspace((int)(unsigned char)q[l-1]))
 			q[--l]=0;
 		putenv(q);
 	}
@@ -1475,9 +1478,10 @@ int i;
 
 			/* No predefined message, look for a TXT record. */
 
-			if ((j=rfc1035_replysearch_all(replyp, hostname,
-				RFC1035_TYPE_TXT,
-				RFC1035_CLASS_IN, 0)) >= 0)
+			if ((j=rfc1035_replysearch_all(&rfc1035_default_resolver,
+						       replyp, hostname,
+						       RFC1035_TYPE_TXT,
+						       RFC1035_CLASS_IN, 0)) >= 0)
 			{
 				rfc1035_rr_gettxt(replyp->allrrs[j], 0, buf);
 				mysetenv(vvarname, buf);
