@@ -2,7 +2,7 @@
 ** Copyright 2000 Double Precision, Inc.
 ** See COPYING for distribution information.
 **
-** $Id: unicode.c,v 1.2 2000/11/24 02:13:41 mrsam Exp $
+** $Id: unicode.c,v 1.4 2002/07/07 21:32:20 mrsam Exp $
 */
 
 #include	"config.h"
@@ -49,6 +49,7 @@ int	i;
 			free(p);
 			return (unicode_chsetlist[i].ptr);
 		}
+	free(p);
 	return (0);
 }
 
@@ -94,9 +95,9 @@ char *unicode_convert_fromchset(const char *txt, const char *from,
 	return (unicode_convert(txt, fromu, to));
 }
 
-//
-// Convert being character sets, except ignore errors.
-//
+/*
+** Convert being character sets, except ignore errors.
+*/
 
 struct ux_buf {
 	char *buffer;
@@ -171,9 +172,10 @@ char *unicode_xconvert(const char *txt, const struct unicode_info *from,
 				return (NULL);
 			}
 
-			// Error converting original text to unicode.
-			// Back up, and convert all the characters up until
-			// the error character.
+			/* Error converting original text to unicode.
+			** Back up, and convert all the characters up until
+			** the error character.
+			*/
 
 			l=dummy;
 
@@ -192,8 +194,9 @@ char *unicode_xconvert(const char *txt, const struct unicode_info *from,
 			}
 		}
 
-		// Ok, now convert unicode to dest charset, using the same
-		// trial-and-error process.
+		/* Ok, now convert unicode to dest charset, using the same
+		** trial-and-error process.
+		*/
 
 		ucptr=uc;
 
